"use strict";
/*
This file is part of uvcc -- USB Video Class (UVC) device configurator.
Copyright (C) 2018, 2019, 2020, 2021 Joel Purra <https://joelpurra.com/>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <https://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const map_obj_1 = __importDefault(require("map-obj"));
const command_1 = require("../types/command");
const flatten_control_values_1 = __importDefault(require("../utilities/flatten-control-values"));
class ExportCommand {
    constructor() {
        assert_1.default.strictEqual(arguments.length, 0);
    }
    async getArguments() {
        return [
            command_1.CommandHandlerArgumentCameraHelper,
        ];
    }
    async execute(...args) {
        assert_1.default.strictEqual(arguments.length, 1);
        const cameraHelper = args[0];
        // NOTE: exporting un-settable values breaks imports because of strict settable value checks.
        // TODO: export also un-settable values with --all flag?
        const settableControls = await cameraHelper.getSettableControls();
        const values = map_obj_1.default(settableControls, (settableControlName, settableControlValue) => [
            settableControlName,
            flatten_control_values_1.default(settableControlValue),
        ]);
        return values;
    }
}
exports.default = ExportCommand;
