"use strict";
/*
This file is part of uvcc -- USB Video Class (UVC) device configurator.
Copyright (C) 2018, 2019, 2020, 2021 Joel Purra <https://joelpurra.com/>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <https://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const bluebird_1 = __importDefault(require("bluebird"));
const stream_to_promise_1 = __importDefault(require("stream-to-promise"));
const command_1 = require("../types/command");
const is_uvcc_controls_1 = __importDefault(require("../utilities/is-uvcc-controls"));
class ImportCommand {
    constructor() {
        assert_1.default.strictEqual(arguments.length, 0);
    }
    async getArguments() {
        return [
            command_1.CommandHandlerArgumentCameraHelper,
        ];
    }
    async execute(...args) {
        assert_1.default.strictEqual(arguments.length, 1);
        const cameraHelper = args[0];
        const stdinTimeout = 1000;
        const controlValues = await bluebird_1.default.try(async () => {
            const buffer = await stream_to_promise_1.default(process.stdin);
            const json = JSON.parse(buffer.toString());
            assert_1.default(typeof json === "object");
            assert_1.default(json !== null);
            return json;
        })
            .timeout(stdinTimeout, `Could not read uvcc configuration from stdin within the ${stdinTimeout} millisecond timeout. Was any data piped in?`)
            .tapCatch((error) => {
            process.stdin.destroy(error);
        });
        assert_1.default(is_uvcc_controls_1.default(controlValues));
        return cameraHelper.setControls(controlValues);
    }
}
exports.default = ImportCommand;
