"use strict";
/*
This file is part of uvcc -- USB Video Class (UVC) device configurator.
Copyright (C) 2018, 2019, 2020, 2021 Joel Purra <https://joelpurra.com/>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <https://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
class Output {
    constructor(enableVerboseOutput) {
        Object.defineProperty(this, "enableVerboseOutput", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: enableVerboseOutput
        });
        assert_1.default.strictEqual(arguments.length, 1);
        assert_1.default(typeof this.enableVerboseOutput === "boolean");
    }
    normal(...args) {
        this.consoleLog(...args);
    }
    error(...args) {
        this.consoleError(...args);
    }
    warning(...args) {
        this.consoleWarn(...args);
    }
    verbose(...args) {
        if (!this.enableVerboseOutput) {
            return undefined;
        }
        this.consoleError(...args);
    }
    consoleLog(...args) {
        // eslint-disable-next-line no-console
        console.log(...args);
    }
    consoleError(...args) {
        // eslint-disable-next-line no-console
        console.error(...args);
    }
    consoleWarn(...args) {
        // eslint-disable-next-line no-console
        console.warn(...args);
    }
}
exports.default = Output;
